st_build_filter_url: Build Sensor Tower Filter URL

View source: R/st_filter_helpers.R

st_build_filter_urlR Documentation

Build Sensor Tower Filter URL

Description

Constructs a URL for the Sensor Tower web interface where you can create custom filters. Visit this URL, configure your filters, and then copy the custom_fields_filter_id from the resulting URL.

Usage

st_build_filter_url(
  os = "unified",
  category = NULL,
  countries = NULL,
  base_url = "https://app.sensortower.com/top-charts"
)

Arguments

os

Character string. Operating system filter. One of "ios", "android", or "unified". Defaults to "unified".

category

Optional. Category ID to pre-select.

countries

Optional. Character vector of country codes to pre-select.

base_url

Character string. Base URL for Sensor Tower. Defaults to "https://app.sensortower.com/top-charts".

Value

Character string. The constructed URL.

Examples

## Not run: 
# Build URL for iOS games in US
url <- st_build_filter_url(os = "ios", category = 6014, countries = "US")

# Open in browser
browseURL(url)

## End(Not run)

sensortowerR documentation built on March 18, 2026, 5:07 p.m.