st_custom_fields_values: Get Custom Fields Values

st_custom_fields_valuesR Documentation

Get Custom Fields Values

Description

Retrieves a list of all accessible custom fields and their possible values. This is useful for discovering what custom fields are available to filter by.

Usage

st_custom_fields_values(
  term = NULL,
  auth_token = NULL,
  base_url = "https://api.sensortower.com"
)

Arguments

term

Optional. Character string. Search term to filter field names.

auth_token

Optional. Character string. Your Sensor Tower API token.

base_url

Optional. Character string. The base URL for the API.

Value

A tibble containing custom fields and their possible values

Examples

## Not run: 
# Get all custom fields
fields <- st_custom_fields_values()

# Search for specific fields
date_fields <- st_custom_fields_values(term = "date")

## End(Not run)


sensortowerR documentation built on March 18, 2026, 5:07 p.m.