st_discover_fields: Discover Available Custom Fields

View source: R/st_custom_fields_workflow.R

st_discover_fieldsR Documentation

Discover Available Custom Fields

Description

Searches and displays available custom fields that can be used for filtering. This is helpful for discovering what fields are available before creating filters.

Usage

st_discover_fields(search_term = NULL, show_values = FALSE, auth_token = NULL)

Arguments

search_term

Optional. Character string to search for in field names

show_values

Logical. Whether to show possible values for each field

auth_token

Optional. Character string. Your Sensor Tower API token.

Value

A tibble with custom fields information

Examples

## Not run: 
# Find all game-related fields
game_fields <- st_discover_fields("game")

# Find all date fields
date_fields <- st_discover_fields("date")

# Show all fields with their values
all_fields <- st_discover_fields(show_values = TRUE)

## End(Not run)


sensortowerR documentation built on March 18, 2026, 5:07 p.m.