| st_custom_fields_values | R Documentation |
Retrieves a list of all accessible custom fields and their possible values. This is useful for discovering what custom fields are available to filter by.
st_custom_fields_values(
term = NULL,
auth_token = NULL,
base_url = "https://api.sensortower.com"
)
term |
Optional. Character string. Search term to filter field names. |
auth_token |
Optional. Character string. Your Sensor Tower API token. |
base_url |
Optional. Character string. The base URL for the API. |
A tibble containing custom fields and their possible values
## Not run:
# Get all custom fields
fields <- st_custom_fields_values()
# Search for specific fields
date_fields <- st_custom_fields_values(term = "date")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.