View source: R/st_custom_fields_workflow.R
| st_discover_fields | R Documentation |
Searches and displays available custom fields that can be used for filtering. This is helpful for discovering what fields are available before creating filters.
st_discover_fields(search_term = NULL, show_values = FALSE, auth_token = NULL)
search_term |
Optional. Character string to search for in field names |
show_values |
Logical. Whether to show possible values for each field |
auth_token |
Optional. Character string. Your Sensor Tower API token. |
A tibble with custom fields information
## Not run:
# Find all game-related fields
game_fields <- st_discover_fields("game")
# Find all date fields
date_fields <- st_discover_fields("date")
# Show all fields with their values
all_fields <- st_discover_fields(show_values = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.