| st_rankings | R Documentation |
Thin v1.0.0 facade that standardizes the app, publisher, and category ranking entrypoints while dispatching to the existing implementations.
st_rankings(
entity = c("app", "publisher", "category"),
os = "ios",
category = NULL,
country = "US",
chart_type = "topfreeapplications",
date = Sys.Date() - 1,
limit = 100,
filter = NULL,
auth_token = NULL
)
entity |
Ranking entity to fetch: '"app"', '"publisher"', or '"category"'. |
os |
Operating system. One of '"ios"', '"android"', or '"unified"'. |
category |
Optional category identifier forwarded to the legacy ranking implementation. |
country |
Two-letter country code. |
chart_type |
Chart type for category rankings. Ignored for app and publisher rankings. |
date |
Ranking date. Accepts a 'Date' object or ISO date string. |
limit |
Positive integer row limit. |
filter |
Optional 'st_filter' object or 24-character filter ID string. |
auth_token |
Optional Sensor Tower API token. |
A tibble with standardized columns 'rank', 'id', 'name', 'os', 'category', 'country', and 'date', plus any entity-specific columns returned by the dispatched implementation.
## Not run:
st_rankings(entity = "app", os = "ios", category = 6014, country = "US")
st_rankings(
entity = "category",
os = "android",
category = "game",
chart_type = "topgrossing",
country = "GB"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.